//////////////////////////////////////////////////////////////////////
//
//   Test script for Kenny Translator
//   by Kohan Ikin (aka SyneRyder)
//
//   LICENSE
//
//   Copyright (c) 2012 namesuppressed.  All rights reserved.
//
//   Redistribution and use in source and binary forms, with or without
//   modification, are permitted provided that the following conditions
//   are met:
//
//   * Redistributions of source code must retain the above copyright
//     notice, this list of conditions and the following disclaimer.
//
//   * Neither the name of namesuppressed nor the names of the
//     contributors may be used to endorse or promote products derived
//     from this software without specific prior written permission.
//
//   * A website link to http://www.namesuppressed.com/kenny/ is
//     greatly appreciated, although not required.
//
//   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
//   "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
//   LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
//   FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
//   COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
//   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
//   BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
//   LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
//   CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
//   LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
//   ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
//   POSSIBILITY OF SUCH DAMAGE.
//
//////////////////////////////////////////////////////////////////////



package main

import (
  "testing";
)



func TestIsKennyspeak(t *testing.T) {
  var expected bool
  var actual bool
  var testdata string
  
  testdata = "mffpmp!"
  expected = true
  actual   = isKennyspeak(testdata)
  if (actual != expected) {
     t.Errorf("Error in isKennyspeak with %s, expected: %t actual: %t", testdata, expected, actual)
  }

  testdata = "Experimental testing!"
  expected = false
  actual   = isKennyspeak(testdata)
  if (actual != expected) {
     t.Errorf("Error in isKennyspeak with %s, expected: %t actual: %t", testdata, expected, actual)
  }

  testdata = "the quick brown fox jumped over 273 lazy dogs!"
  expected = false
  actual   = isKennyspeak(testdata)
  if (actual != expected) {
     t.Errorf("Error in isKennyspeak with %s, expected: %t actual: %t", testdata, expected, actual)
  }

  testdata = "THE QUICK BROWN FOX JUMPED OVER 273 LAZY DOGS!"
  expected = false
  actual   = isKennyspeak(testdata)
  if (actual != expected) {
     t.Errorf("Error in isKennyspeak with %s, expected: %t actual: %t", testdata, expected, actual)
  }
}



func TestKennify(t *testing.T) {
  var expected string
  var actual string
  var testdata string
  
  expected = "ik!"
  actual   = kennify("mffpmp!")
  if (actual != expected) {
     t.Errorf("Error in kennify with mffpmp!, expected: %s actual: %s", expected, actual)
  }
  
  expected = "Fmpmppfmmfmpmffpppmfm mppfpfpfmmpppffmffppmmpppppfmp!"
  actual   = kennify("Testing experiment!")
  if (actual != expected) {
     t.Errorf("Error in kennify with 'Testing experiment!', expected: %s actual: %s", expected, actual)
  } 

  testdata = "the quick brown fox jumped over 273 lazy dogs!"
  expected = "fmpmfpmpp pfpfmfmffmmfpmp mmppffppffppppp mpfppffpf pmmfmfppmpfmmppmpm ppffpmmpppff 273 pmfmmmffpffm mpmppfmfmfmm!"
  actual   = kennify(testdata)
  if (actual != expected) {
     t.Errorf("Error in kennify with %s, expected: %s actual: %s", testdata, expected, actual)
  }

  testdata = "fmpmfpmpp pfpfmfmffmmfpmp mmppffppffppppp mpfppffpf pmmfmfppmpfmmppmpm ppffpmmpppff 273 pmfmmmffpffm mpmppfmfmfmm!"
  expected = "the quick brown fox jumped over 273 lazy dogs!"
  actual   = kennify(testdata)
  if (actual != expected) {
     t.Errorf("Error in kennify with %s, expected: %s actual: %s", testdata, expected, actual)
  }

  testdata = "THE QUICK BROWN FOX JUMPED OVER 273 LAZY DOGS!"
  expected = "FmpMfpMpp PfpFmfMffMmfPmp MmpPffPpfFppPpp MpfPpfFpf PmmFmfPpmPfmMppMpm PpfFpmMppPff 273 PmfMmmFfpFfm MpmPpfMfmFmm!"
  actual   = kennify(testdata)
  if (actual != expected) {
     t.Errorf("Error in kennify with %s, expected: %s actual: %s", testdata, expected, actual)
  }

  testdata = "FmpMfpMpp PfpFmfMffMmfPmp MmpPffPpfFppPpp MpfPpfFpf PmmFmfPpmPfmMppMpm PpfFpmMppPff 273 PmfMmmFfpFfm MpmPpfMfmFmm!"
  expected = "THE QUICK BROWN FOX JUMPED OVER 273 LAZY DOGS!"
  actual   = kennify(testdata)
  if (actual != expected) {
     t.Errorf("Error in kennify with %s, expected: %s actual: %s", testdata, expected, actual)
  }
}



func TestEasterEggs(t *testing.T) {
  var expected string
  var actual string
  
  expected = "oh yes he is"
  actual   = kennify("greggles is a steggles")
  if (actual != expected) {
     t.Errorf("Greggles easter egg not implemented.")
  }

  expected = "fittzuzfa!"
  actual   = kennify("hellokohan")
  if (actual != expected) {
     t.Errorf("hellokohan easter egg not implemented.")
  }

  expected = "\"ik!\" is not an easter egg."
  actual   = kennify("ik!")
  if (actual != expected) {
     t.Errorf("ik! easter egg not implemented.")
  }

  expected = "\"ik\" was Simon's idea, not mine!"
  actual   = kennify("ik")
  if (actual != expected) {
     t.Errorf("ik easter egg not implemented.")
  }

  expected = "\"Sad eggs....\"\n\n- Ingy\nwww.ingy.net"
  actual   = kennify("ingy")
  if (actual != expected) {
     t.Errorf("ingy easter egg not implemented.")
  }

  expected = "Pat Quincy Upbottom"
  actual   = kennify("CS302")
  if (actual != expected) {
     t.Errorf("CS302 easter egg not implemented.")
  }

  //expected = "Aeolas thinks KennySpeak sounds like someone getting head....\n\nhttp://pub28.ezboard.com/ftweetysnestofreaksfrm1.showMessage?topicID=701.topic"
  //actual   = kennify("Aeolas")
  //if (actual != expected) {
  //   t.Errorf("Aeolas easter egg not implemented.")
  //}
}
